/*  $Id: dbz.h,v 1.4 1999/03/05 11:20:33 src Exp $
 *
 *  for dbz version 6
 *
 *  $Log: dbz.h,v $
 *  Revision 1.4  1999/03/05 11:20:33  src
 *  Delayed decision of dbz v3 vz. 6 to runtime.
 *
 *  Revision 1.3  1998/07/12 09:39:19  src
 *  NewsX version 1.0
 */

/*
 *  v6
 *
 *  DO_TAGGED_HASH enabled if we use $HISTORY.pag
 *  otherwise we'll use $HISTORY.index and $HISTORY.hash
 */
#include "configdata.h"
#include "clibrary.h"
#include "libinn.h"

#include "dbz-v6.h"
